r19939 - gnucash/trunk/src - Replace more obsolete #define'd function names by their current names.

Christian Stimming cstim at code.gnucash.org
Tue Dec 14 15:22:48 EST 2010


Author: cstim
Date: 2010-12-14 15:22:48 -0500 (Tue, 14 Dec 2010)
New Revision: 19939
Trac: http://svn.gnucash.org/trac/changeset/19939

Removed:
   gnucash/trunk/src/engine/QueryCore.h
   gnucash/trunk/src/engine/QueryObject.h
   gnucash/trunk/src/engine/QueryP.h
   gnucash/trunk/src/engine/gncObject.h
Modified:
   gnucash/trunk/src/backend/xml/io-gncxml-v1.c
   gnucash/trunk/src/business/business-gnome/business-gnome-utils.c
   gnucash/trunk/src/business/business-gnome/dialog-invoice.c
   gnucash/trunk/src/business/business-gnome/search-owner.c
   gnucash/trunk/src/engine/CMakeLists.txt
   gnucash/trunk/src/engine/Makefile.am
   gnucash/trunk/src/engine/Query.c
   gnucash/trunk/src/engine/Query.h
   gnucash/trunk/src/engine/engine-helpers.c
   gnucash/trunk/src/engine/engine-helpers.h
   gnucash/trunk/src/engine/gncIDSearch.c
   gnucash/trunk/src/engine/gncIDSearch.h
   gnucash/trunk/src/engine/test-core/test-engine-stuff.c
   gnucash/trunk/src/engine/test-core/test-engine-stuff.h
   gnucash/trunk/src/engine/test/test-query.c
   gnucash/trunk/src/engine/test/test-scm-query.c
   gnucash/trunk/src/gnome-search/dialog-search.c
   gnucash/trunk/src/gnome-search/gnc-general-search.c
   gnucash/trunk/src/gnome-search/search-account.c
   gnucash/trunk/src/gnome-search/search-boolean.c
   gnucash/trunk/src/gnome-search/search-core-type.c
   gnucash/trunk/src/gnome-search/search-core-type.h
   gnucash/trunk/src/gnome-search/search-date.c
   gnucash/trunk/src/gnome-search/search-double.c
   gnucash/trunk/src/gnome-search/search-int64.c
   gnucash/trunk/src/gnome-search/search-numeric.c
   gnucash/trunk/src/gnome-search/search-reconciled.c
   gnucash/trunk/src/gnome-search/search-string.c
   gnucash/trunk/src/gnome-utils/gnc-query-list.c
   gnucash/trunk/src/gnome-utils/search-param.c
   gnucash/trunk/src/gnome/dialog-find-transactions.c
   gnucash/trunk/src/gnome/reconcile-list.c
   gnucash/trunk/src/register/ledger-core/gnc-ledger-display.c
Log:
Replace more obsolete #define'd function names by their current names.

Modified: gnucash/trunk/src/backend/xml/io-gncxml-v1.c
===================================================================
--- gnucash/trunk/src/backend/xml/io-gncxml-v1.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/backend/xml/io-gncxml-v1.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -36,7 +36,6 @@
 #include "Account.h"
 #include "AccountP.h"
 #include "Query.h"
-#include "QueryP.h"
 #include "Scrub.h"
 #include "Transaction.h"
 #include "TransactionP.h"

Modified: gnucash/trunk/src/business/business-gnome/business-gnome-utils.c
===================================================================
--- gnucash/trunk/src/business/business-gnome/business-gnome-utils.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/business/business-gnome/business-gnome-utils.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -41,7 +41,7 @@
 #include "gncInvoice.h"
 
 #include "gnc-general-search.h"
-#include "gncObject.h"
+#include "qof.h"
 #include "business-gnome-utils.h"
 #include "dialog-customer.h"
 #include "dialog-job.h"

Modified: gnucash/trunk/src/business/business-gnome/dialog-invoice.c
===================================================================
--- gnucash/trunk/src/business/business-gnome/dialog-invoice.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/business/business-gnome/dialog-invoice.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -30,9 +30,9 @@
 #include <libguile.h>
 #include "swig-runtime.h"
 
-#include "gncObject.h"
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
+#include "qof.h"
 
 #include "dialog-utils.h"
 #include "gnc-component-manager.h"
@@ -2670,7 +2670,7 @@
 {
     QofIdType type = GNC_INVOICE_MODULE_NAME;
     Query *q;
-    QueryPredData_t pred_data;
+    QofQueryPredData* pred_data;
     time_t end_date;
     GList *res;
     gint len;

Modified: gnucash/trunk/src/business/business-gnome/search-owner.c
===================================================================
--- gnucash/trunk/src/business/business-gnome/search-owner.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/business/business-gnome/search-owner.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#include "QueryCore.h"
+#include "qof.h"
 #include "gnc-ui-util.h"
 #include "gnc-gui-query.h"
 #include "gncOwner.h"
@@ -42,7 +42,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_owner_class_init	(GNCSearchOwnerClass *class);
 static void gnc_search_owner_init	(GNCSearchOwner *gspaper);
@@ -303,7 +303,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchOwner *fi = (GNCSearchOwner *)fe;
     GNCSearchOwnerPrivate *priv;

Modified: gnucash/trunk/src/engine/CMakeLists.txt
===================================================================
--- gnucash/trunk/src/engine/CMakeLists.txt	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/CMakeLists.txt	2010-12-14 20:22:48 UTC (rev 19939)
@@ -25,8 +25,6 @@
   SX-book.h
   SX-ttinfo.h
   Query.h
-  QueryObject.h
-  QueryCore.h
   Scrub.h
   Scrub2.h
   Scrub3.h
@@ -46,7 +44,6 @@
   gnc-pricedb.h
   gnc-session-scm.h
   gnc-session.h
-  gncObject.h
   kvp-scm.h
   policy.h
   gncAddress.h

Modified: gnucash/trunk/src/engine/Makefile.am
===================================================================
--- gnucash/trunk/src/engine/Makefile.am	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/Makefile.am	2010-12-14 20:22:48 UTC (rev 19939)
@@ -72,8 +72,6 @@
   SX-book.h \
   SX-ttinfo.h \
   Query.h \
-  QueryObject.h \
-  QueryCore.h \
   Scrub.h \
   Scrub2.h \
   Scrub3.h \
@@ -93,7 +91,6 @@
   gnc-pricedb.h \
   gnc-session.h \
   gnc-session-scm.h \
-  gncObject.h \
   kvp-scm.h \
   policy.h \
   gncAddress.h \
@@ -124,7 +121,6 @@
 
 noinst_HEADERS = \
   AccountP.h \
-  QueryP.h \
   ScrubP.h \
   SplitP.h \
   SX-book.h \

Modified: gnucash/trunk/src/engine/Query.c
===================================================================
--- gnucash/trunk/src/engine/Query.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/Query.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -63,7 +63,7 @@
  ********************************************************************/
 
 SplitList *
-xaccQueryGetSplitsUniqueTrans(Query *q)
+xaccQueryGetSplitsUniqueTrans(QofQuery *q)
 {
     GList       * splits = qof_query_run(q);
     GList       * current;
@@ -115,7 +115,7 @@
 }
 
 TransList *
-xaccQueryGetTransactions (Query * q, query_txn_match_t runtype)
+xaccQueryGetTransactions (QofQuery * q, query_txn_match_t runtype)
 {
     GList       * splits = qof_query_run(q);
     GList       * current = NULL;
@@ -186,7 +186,7 @@
 }
 
 LotList *
-xaccQueryGetLots (Query * q, query_txn_match_t runtype)
+xaccQueryGetLots (QofQuery * q, query_txn_match_t runtype)
 {
     GList       * splits = qof_query_run(q);
     GList       * current = NULL;
@@ -234,7 +234,7 @@
  *******************************************************************/
 
 void
-xaccQueryAddAccountMatch(Query *q, AccountList *acct_list,
+xaccQueryAddAccountMatch(QofQuery *q, AccountList *acct_list,
                          QofGuidMatch how, QofQueryOp op)
 {
     GList *list = NULL;
@@ -265,7 +265,7 @@
 }
 
 void
-xaccQueryAddAccountGUIDMatch(Query *q, AccountGUIDList *guid_list,
+xaccQueryAddAccountGUIDMatch(QofQuery *q, AccountGUIDList *guid_list,
                              QofGuidMatch how, QofQueryOp op)
 {
     QofQueryPredData *pred_data;
@@ -295,7 +295,7 @@
 }
 
 void
-xaccQueryAddSingleAccountMatch(Query *q, Account *acc, QofQueryOp op)
+xaccQueryAddSingleAccountMatch(QofQuery *q, Account *acc, QofQueryOp op)
 {
     GList *list;
     const GncGUID *guid;
@@ -312,7 +312,7 @@
 }
 
 void
-xaccQueryAddStringMatch (Query* q, const char *matchstring,
+xaccQueryAddStringMatch (QofQuery* q, const char *matchstring,
                          gboolean case_sens, gboolean use_regexp,
                          QofQueryOp op,
                          const char * path, ...)
@@ -339,7 +339,7 @@
 }
 
 void
-xaccQueryAddNumericMatch (Query *q, gnc_numeric amount, QofNumericMatch sign,
+xaccQueryAddNumericMatch (QofQuery *q, gnc_numeric amount, QofNumericMatch sign,
                           QofQueryCompare how, QofQueryOp op,
                           const char * path, ...)
 {
@@ -371,12 +371,12 @@
  */
 
 void
-xaccQueryAddDateMatchTS (Query * q,
+xaccQueryAddDateMatchTS (QofQuery * q,
                          gboolean use_start, Timespec sts,
                          gboolean use_end, Timespec ets,
                          QofQueryOp op)
 {
-    Query *tmp_q = NULL;
+    QofQuery *tmp_q = NULL;
     QofQueryPredData *pred_data;
     GSList *param_list;
 
@@ -416,7 +416,7 @@
 }
 
 void
-xaccQueryGetDateMatchTS (Query * q,
+xaccQueryGetDateMatchTS (QofQuery * q,
                          Timespec * sts,
                          Timespec * ets)
 {
@@ -448,7 +448,7 @@
  ********************************************************************/
 
 void
-xaccQueryAddDateMatch(Query * q,
+xaccQueryAddDateMatch(QofQuery * q,
                       gboolean use_start, int sday, int smonth, int syear,
                       gboolean use_end, int eday, int emonth, int eyear,
                       QofQueryOp op)
@@ -467,7 +467,7 @@
  ********************************************************************/
 
 void
-xaccQueryAddDateMatchTT(Query * q,
+xaccQueryAddDateMatchTT(QofQuery * q,
                         gboolean use_start,
                         time_t stt,
                         gboolean use_end,
@@ -490,7 +490,7 @@
 }
 
 void
-xaccQueryGetDateMatchTT (Query * q,
+xaccQueryGetDateMatchTT (QofQuery * q,
                          time_t * stt,
                          time_t * ett)
 {
@@ -504,7 +504,7 @@
 }
 
 void
-xaccQueryAddClearedMatch(Query * q, cleared_match_t how, QofQueryOp op)
+xaccQueryAddClearedMatch(QofQuery * q, cleared_match_t how, QofQueryOp op)
 {
     QofQueryPredData *pred_data;
     GSList *param_list;
@@ -536,7 +536,7 @@
 }
 
 void
-xaccQueryAddGUIDMatch(Query * q, const GncGUID *guid,
+xaccQueryAddGUIDMatch(QofQuery * q, const GncGUID *guid,
                       QofIdType id_type, QofQueryOp op)
 {
     GSList *param_list = NULL;
@@ -588,7 +588,7 @@
  *******************************************************************/
 
 time_t
-xaccQueryGetEarliestDateFound(Query * q)
+xaccQueryGetEarliestDateFound(QofQuery * q)
 {
     GList * spl;
     Split * sp;
@@ -617,7 +617,7 @@
  *******************************************************************/
 
 time_t
-xaccQueryGetLatestDateFound(Query * q)
+xaccQueryGetLatestDateFound(QofQuery * q)
 {
     Split  * sp;
     GList  * spl;
@@ -639,7 +639,7 @@
 }
 
 void
-xaccQueryAddDescriptionMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddDescriptionMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                              QofQueryOp o)
 {
     xaccQueryAddStringMatch ((q), (m), (c), (r), (o), SPLIT_TRANS,
@@ -647,7 +647,7 @@
 }
 
 void
-xaccQueryAddNumberMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddNumberMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                         QofQueryOp o)
 {
     xaccQueryAddStringMatch ((q), (m), (c), (r), (o), SPLIT_TRANS,
@@ -655,21 +655,21 @@
 }
 
 void
-xaccQueryAddActionMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddActionMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                         QofQueryOp o)
 {
     xaccQueryAddStringMatch ((q), (m), (c), (r), (o), SPLIT_ACTION, NULL);
 }
 
 void
-xaccQueryAddMemoMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddMemoMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                       QofQueryOp o)
 {
     xaccQueryAddStringMatch ((q), (m), (c), (r), (o), SPLIT_MEMO, NULL);
 }
 
 void
-xaccQueryAddValueMatch(Query *q, gnc_numeric amt, QofNumericMatch sgn,
+xaccQueryAddValueMatch(QofQuery *q, gnc_numeric amt, QofNumericMatch sgn,
                        QofQueryCompare how, QofQueryOp op)
 {
     xaccQueryAddNumericMatch ((q), (amt), (sgn), (how), (op),
@@ -677,7 +677,7 @@
 }
 
 void
-xaccQueryAddSharePriceMatch(Query *q, gnc_numeric amt, QofQueryCompare how,
+xaccQueryAddSharePriceMatch(QofQuery *q, gnc_numeric amt, QofQueryCompare how,
                             QofQueryOp op)
 {
     xaccQueryAddNumericMatch ((q), (amt), QOF_NUMERIC_MATCH_ANY, (how), (op),
@@ -685,7 +685,7 @@
 }
 
 void
-xaccQueryAddSharesMatch(Query *q, gnc_numeric amt, QofQueryCompare how,
+xaccQueryAddSharesMatch(QofQuery *q, gnc_numeric amt, QofQueryCompare how,
                         QofQueryOp op)
 {
     xaccQueryAddNumericMatch ((q), (amt), QOF_NUMERIC_MATCH_ANY, (how), (op),
@@ -693,7 +693,7 @@
 }
 
 void
-xaccQueryAddBalanceMatch(Query *q, QofQueryCompare bal, QofQueryOp op)
+xaccQueryAddBalanceMatch(QofQuery *q, QofQueryCompare bal, QofQueryOp op)
 {
     xaccQueryAddNumericMatch(
         (q), gnc_numeric_zero(), QOF_NUMERIC_MATCH_ANY,

Modified: gnucash/trunk/src/engine/Query.h
===================================================================
--- gnucash/trunk/src/engine/QueryCore.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/QueryCore.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1,4 +0,0 @@
-
-#include "qof.h"
-
-#define QueryPredData_t QofQueryPredData*

Deleted: gnucash/trunk/src/engine/QueryObject.h
===================================================================
--- gnucash/trunk/src/engine/QueryObject.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/QueryObject.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1,7 +0,0 @@
-
-#include "qof.h"
-
-#define query_object_def _QofParam
-#define QueryObjectDef QofParam
-
-

Deleted: gnucash/trunk/src/engine/QueryP.h
===================================================================
--- gnucash/trunk/src/engine/QueryP.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/QueryP.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1,169 +0,0 @@
-/********************************************************************\
- * QueryP.h : private, non-portable Query API structs               *
- * Copyright 2000 Bill Gribble <grib at billgribble.com>               *
- * Copyright 2002 Linas Vepstas <linas at linas.org>                   *
- *                                                                  *
- * This program is free software; you can redistribute it and/or    *
- * modify it under the terms of the GNU General Public License as   *
- * published by the Free Software Foundation; either version 2 of   *
- * the License, or (at your option) any later version.              *
- *                                                                  *
- * This program is distributed in the hope that it will be useful,  *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
- * GNU General Public License for more details.                     *
- *                                                                  *
- * You should have received a copy of the GNU General Public License*
- * along with this program; if not, contact:                        *
- *                                                                  *
- * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
- * Boston, MA  02110-1301,  USA       gnu at gnu.org                   *
-\********************************************************************/
-
-#ifndef GNUCASH_QUERY_P_H
-#define GNUCASH_QUERY_P_H
-
-#include "Query.h"
-
-#if 0
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-} BasePredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    acct_match_t    how;
-    AccountList     *accounts;
-    AccountGUIDList *account_guids;
-} AccountPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    amt_match_t     how;
-    amt_match_sgn_t amt_sgn;
-    double          amount;
-} AmountPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    balance_match_t how;
-} BalancePredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    book_match_t    how;
-    BookList        *books;
-    BookGUIDList    *book_guids;
-} BookPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    cleared_match_t how;
-} ClearedPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    GncGUID            guid;
-    QofIdType       id_type;
-} GUIDPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    int             use_start;
-    Timespec        start;
-    int             use_end;
-    Timespec        end;
-} DatePredicateData;
-
-typedef struct
-{
-    pd_type_t         type;
-    pr_type_t         term_type;
-    int               sense;
-    kvp_match_t       how;
-    kvp_match_where_t where;
-    GSList           *path;
-    KvpValue        *value;
-} KVPPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    int             how;
-    int             data;
-} MiscPredicateData;
-
-typedef struct
-{
-    pd_type_t       type;
-    pr_type_t       term_type;
-    int             sense;
-    int             case_sens;
-    int             use_regexp;
-    char           *matchstring;
-    regex_t         compiled;
-} StringPredicateData;
-
-typedef union
-{
-    pd_type_t            type;
-    BasePredicateData    base;
-    AccountPredicateData acct;
-    AmountPredicateData  amount;
-    BalancePredicateData balance;
-    BookPredicateData    book;
-    ClearedPredicateData cleared;
-    DatePredicateData    date;
-    GUIDPredicateData    guid;
-    KVPPredicateData     kvp;
-    StringPredicateData  str;
-    MiscPredicateData    misc;
-} PredicateData;
-
-typedef int (* Predicate)(Split * to_test, PredicateData * test_data);
-
-typedef struct
-{
-    PredicateData data;
-    Predicate     p;
-} QueryTerm;
-
-void xaccQueryAddMiscMatch(Query * q, Predicate p, int how, int data,
-                           QofQueryOp op);
-
-void xaccQueryAddPredicate (Query * q, PredicateData *pred, QofQueryOp op);
-
-/* This is useful for network systems */
-Predicate xaccQueryGetPredicate (pr_type_t term_type);
-
-#endif /* 0 */
-
-#endif /* GNUCASH_QUERY_P_H */

Modified: gnucash/trunk/src/engine/engine-helpers.c
===================================================================
--- gnucash/trunk/src/engine/engine-helpers.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/engine-helpers.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1124,7 +1124,7 @@
         qof_query_add_term (q, path, pd, QOF_QUERY_OR);
         if (inverted)
         {
-            Query *outq = qof_query_invert (q);
+            QofQuery *outq = qof_query_invert (q);
             qof_query_destroy (q);
             q = outq;
         }
@@ -1491,7 +1491,7 @@
 
     if (ok)
     {
-        Query *out_q;
+        QofQuery *out_q;
 
         if (sense)
             out_q = q;
@@ -1508,7 +1508,7 @@
     return NULL;
 }
 
-static Query *
+static QofQuery *
 gnc_scm2query_term_query (SCM query_term_scm, query_version_t vers)
 {
     switch (vers)
@@ -1551,10 +1551,10 @@
     return scm_reverse (or_terms);
 }
 
-static Query *
+static QofQuery *
 gnc_scm2query_and_terms (SCM and_terms, query_version_t vers)
 {
-    Query *q = NULL;
+    QofQuery *q = NULL;
 
     if (!scm_is_list (and_terms))
         return NULL;
@@ -1570,8 +1570,8 @@
             q = gnc_scm2query_term_query (term, vers);
         else
         {
-            Query *q_and;
-            Query *q_new;
+            QofQuery *q_and;
+            QofQuery *q_new;
 
             q_and = gnc_scm2query_term_query (term, vers);
 
@@ -1591,10 +1591,10 @@
     return q;
 }
 
-static Query *
+static QofQuery *
 gnc_scm2query_or_terms (SCM or_terms, query_version_t vers)
 {
-    Query *q = NULL;
+    QofQuery *q = NULL;
 
     if (!scm_is_list (or_terms))
         return NULL;
@@ -1612,8 +1612,8 @@
             q = gnc_scm2query_and_terms (and_terms, vers);
         else
         {
-            Query *q_or;
-            Query *q_new;
+            QofQuery *q_or;
+            QofQuery *q_new;
 
             q_or = gnc_scm2query_and_terms (and_terms, vers);
 
@@ -1856,10 +1856,10 @@
     return path;
 }
 
-static Query *
+static QofQuery *
 gnc_scm2query_v1 (SCM query_scm)
 {
-    Query *q = NULL;
+    QofQuery *q = NULL;
     gboolean ok = TRUE;
     const gchar * primary_sort = NULL;
     const gchar * secondary_sort = NULL;
@@ -2008,10 +2008,10 @@
     return NULL;
 }
 
-static Query *
+static QofQuery *
 gnc_scm2query_v2 (SCM query_scm)
 {
-    Query *q = NULL;
+    QofQuery *q = NULL;
     gboolean ok = TRUE;
     const gchar * search_for = NULL;
     GSList *sp1 = NULL, *sp2 = NULL, *sp3 = NULL;
@@ -2142,12 +2142,12 @@
     return NULL;
 }
 
-Query *
+QofQuery *
 gnc_scm2query (SCM query_scm)
 {
     SCM q_type;
     const gchar *type;
-    Query *q = NULL;
+    QofQuery *q = NULL;
 
     /* Not a list or NULL?  No need to go further */
     if (!scm_is_list (query_scm) || scm_is_null (query_scm))

Modified: gnucash/trunk/src/engine/engine-helpers.h
===================================================================
--- gnucash/trunk/src/engine/engine-helpers.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/engine-helpers.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -60,8 +60,8 @@
 /* These two functions convert a query object into a scheme
  * representation of the query and vice-versa. They do not
  * simply convert a query pointer to a guile query pointer! */
-SCM gnc_query2scm (Query * q);
-Query * gnc_scm2query (SCM query_scm);
+SCM gnc_query2scm (QofQuery * q);
+QofQuery * gnc_scm2query (SCM query_scm);
 
 SCM gnc_gint64_to_scm(const gint64 x);
 gint64 gnc_scm_to_gint64(SCM num);

Modified: gnucash/trunk/src/engine/gncIDSearch.c
===================================================================
--- gnucash/trunk/src/engine/gncIDSearch.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/gncIDSearch.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -79,7 +79,7 @@
     GList *result;
     QofQuery *q;
     gint len;
-    QueryPredData_t string_pred_data;
+    QofQueryPredData* string_pred_data;
     g_return_val_if_fail (type, NULL);
     g_return_val_if_fail (id, NULL);
     g_return_val_if_fail (book, NULL);

Modified: gnucash/trunk/src/engine/gncIDSearch.h
===================================================================
--- gnucash/trunk/src/engine/gncIDSearch.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/gncIDSearch.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -32,8 +32,8 @@
 #include "gncInvoice.h"
 #include "gncBusiness.h"
 // query
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
 #include "GNCId.h"
 
 

Deleted: gnucash/trunk/src/engine/gncObject.h
===================================================================
--- gnucash/trunk/src/engine/gncObject.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/gncObject.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1 +0,0 @@
-#include "qof.h"

Modified: gnucash/trunk/src/engine/test/test-query.c
===================================================================
--- gnucash/trunk/src/engine/test/test-query.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/test/test-query.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -36,7 +36,7 @@
 {
     QofBook *book = data;
     GList *list;
-    Query *q;
+    QofQuery *q;
 
     q = make_trans_query (trans, ALL_QT);
     qof_query_set_book (q, book);

Modified: gnucash/trunk/src/engine/test/test-scm-query.c
===================================================================
--- gnucash/trunk/src/engine/test/test-scm-query.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/test/test-scm-query.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -12,10 +12,10 @@
 
 
 static void
-test_query (Query *q)
+test_query (QofQuery *q)
 {
     SCM scm_q;
-    Query *q2;
+    QofQuery *q2;
 
     scm_q = gnc_query2scm (q);
 
@@ -42,7 +42,7 @@
 static void
 run_tests (void)
 {
-    Query *q;
+    QofQuery *q;
     int i;
 
     test_query (NULL);

Modified: gnucash/trunk/src/engine/test-core/test-engine-stuff.c
===================================================================
--- gnucash/trunk/src/engine/test-core/test-engine-stuff.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/test-core/test-engine-stuff.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -1657,7 +1657,7 @@
 } sort_type_t;
 
 static void
-set_query_sort (Query *q, sort_type_t sort_code)
+set_query_sort (QofQuery *q, sort_type_t sort_code)
 {
     GSList *p1 = NULL, *p2 = NULL, *p3 = NULL, *standard;
 
@@ -1712,10 +1712,10 @@
     qof_query_set_sort_order (q, p1, p2, p3);
 }
 
-Query *
+QofQuery *
 get_random_query(void)
 {
-    Query *q;
+    QofQuery *q;
     int num_terms;
 
     num_terms = get_random_int_in_range (1, 3);
@@ -1972,7 +1972,7 @@
 {
     QofIdType where;
     GSList *path;
-    Query *q;
+    QofQuery *q;
 } KVPQueryData;
 
 static void
@@ -1997,7 +1997,7 @@
 }
 
 static void
-add_kvp_query (Query *q, KvpFrame *frame, QofIdType where)
+add_kvp_query (QofQuery *q, KvpFrame *frame, QofIdType where)
 {
     KVPQueryData kqd;
 
@@ -2036,12 +2036,12 @@
     }
 }
 
-Query *
+QofQuery *
 make_trans_query (Transaction *trans, TestQueryTypes query_types)
 {
     Account *a;
     gnc_numeric n;
-    Query *q;
+    QofQuery *q;
     Split *s;
 
     if (query_types == RANDOM_QT)

Modified: gnucash/trunk/src/engine/test-core/test-engine-stuff.h
===================================================================
--- gnucash/trunk/src/engine/test-core/test-engine-stuff.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/test-core/test-engine-stuff.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -64,8 +64,8 @@
     ALL_QT         = (1 << 8) - 1
 } TestQueryTypes;
 
-Query * get_random_query(void);
-Query * make_trans_query (Transaction *trans, TestQueryTypes query_types);
+QofQuery * get_random_query(void);
+QofQuery * make_trans_query (Transaction *trans, TestQueryTypes query_types);
 TestQueryTypes get_random_query_type (void);
 void trans_query_include_price (gboolean include_amounts);
 

Modified: gnucash/trunk/src/gnome/dialog-find-transactions.c
===================================================================
--- gnucash/trunk/src/gnome/dialog-find-transactions.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome/dialog-find-transactions.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -28,9 +28,9 @@
 
 #include "gnc-ui-util.h"
 #include "Query.h"
-#include "QueryCore.h"
 #include "qof.h"
-#include "QueryObject.h"
+#include "qof.h"
+#include "qof.h"
 #include "SX-book.h"
 #include "Transaction.h"
 #include "dialog-find-transactions.h"

Modified: gnucash/trunk/src/gnome/reconcile-list.c
===================================================================
--- gnucash/trunk/src/gnome/reconcile-list.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome/reconcile-list.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -28,8 +28,8 @@
 #include <glib/gi18n.h>
 
 #include "gnc-date.h"
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
 #include "Transaction.h"
 #include "gnc-ui-util.h"
 #include "gnc-gconf-utils.h"

Modified: gnucash/trunk/src/gnome-search/dialog-search.c
===================================================================
--- gnucash/trunk/src/gnome-search/dialog-search.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/dialog-search.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -35,10 +35,10 @@
 #include "gnc-gui-query.h"
 #include "gnc-query-list.h"
 #include "gnc-gconf-utils.h"
-#include "gncObject.h"
 #include "qof.h"
-#include "QueryObject.h"
-#include "QueryCore.h"
+#include "qof.h"
+#include "qof.h"
+#include "qof.h"
 
 #include "Transaction.h"	/* for the SPLIT_* and TRANS_* */
 
@@ -352,7 +352,7 @@
     QofQuery *q, *q2, *new_q;
     GList *node;
     QofQueryOp op;
-    QueryPredData_t pdata;
+    QofQueryPredData* pdata;
 
     if (sw->grouping == GNC_SEARCH_MATCH_ANY)
         op = QOF_QUERY_OR;

Modified: gnucash/trunk/src/gnome-search/gnc-general-search.c
===================================================================
--- gnucash/trunk/src/gnome-search/gnc-general-search.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/gnc-general-search.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -37,9 +37,9 @@
 #include <stdio.h>
 
 #include "gnc-component-manager.h"
-#include "QueryCore.h"
-#include "QueryObject.h"
-#include "gncObject.h"
+#include "qof.h"
+#include "qof.h"
+#include "qof.h"
 #include "gnc-general-search.h"
 
 #define GNCGENERALSEARCH_CLASS	"gnc-general-search-widget"

Modified: gnucash/trunk/src/gnome-search/search-account.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-account.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-account.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 
 #include "Account.h"
-#include "QueryCore.h"
+#include "qof.h"
 #include "gnc-tree-view-account.h"
 #include "gnc-gui-query.h"
 
@@ -41,7 +41,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_account_class_init	(GNCSearchAccountClass *class);
 static void gnc_search_account_init	(GNCSearchAccount *gspaper);
@@ -316,7 +316,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchAccountPrivate *priv;
     GNCSearchAccount *fi = (GNCSearchAccount *)fe;

Modified: gnucash/trunk/src/gnome-search/search-boolean.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-boolean.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-boolean.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#include "QueryCore.h"
+#include "qof.h"
 
 #include "search-boolean.h"
 #include "search-core-utils.h"
@@ -38,7 +38,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_boolean_class_init	(GNCSearchBooleanClass *class);
 static void gnc_search_boolean_init	(GNCSearchBoolean *gspaper);
@@ -211,7 +211,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchBoolean *fi = (GNCSearchBoolean *)fe;
 

Modified: gnucash/trunk/src/gnome-search/search-core-type.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-core-type.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-core-type.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -26,8 +26,8 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
 #include "Account.h"		/* for ACCOUNT_MATCH_ALL_TYPE */
 #include "Transaction.h"	/* for RECONCILED_MATCH_TYPE */
 
@@ -193,7 +193,7 @@
  *
  * Return value:
  **/
-QueryPredData_t
+QofQueryPredData*
 gnc_search_core_type_get_predicate (GNCSearchCoreType *fe)
 {
     return GNC_SEARCH_CORE_TYPE_GET_CLASS (fe)->get_predicate(fe);

Modified: gnucash/trunk/src/gnome-search/search-core-type.h
===================================================================
--- gnucash/trunk/src/gnome-search/search-core-type.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-core-type.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -22,8 +22,8 @@
 #ifndef _GNCSEARCH_CORE_TYPE_H
 #define _GNCSEARCH_CORE_TYPE_H
 
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
 #include "search-param.h"
 
 #define GNC_TYPE_SEARCH_CORE_TYPE		(gnc_search_core_type_get_type ())
@@ -49,7 +49,7 @@
     gboolean		(*validate) (GNCSearchCoreType *fe);
     GNCSearchCoreType *	(*clone) (GNCSearchCoreType *fe);
     GtkWidget *		(*get_widget) (GNCSearchCoreType *);
-    QueryPredData_t	(*get_predicate) (GNCSearchCoreType *);
+    QofQueryPredData*	(*get_predicate) (GNCSearchCoreType *);
 
     /* signals */
 } GNCSearchCoreTypeClass;
@@ -67,7 +67,7 @@
 gboolean        	gnc_search_core_type_validate (GNCSearchCoreType *fe);
 GNCSearchCoreType *	gnc_search_core_type_clone (GNCSearchCoreType *fe);
 GtkWidget *		gnc_search_core_type_get_widget (GNCSearchCoreType *fe);
-QueryPredData_t		gnc_search_core_type_get_predicate (GNCSearchCoreType *fe);
+QofQueryPredData*		gnc_search_core_type_get_predicate (GNCSearchCoreType *fe);
 
 /* Register a new type in the Core Type Database */
 typedef GNCSearchCoreType * (*GNCSearchCoreNew) (void);

Modified: gnucash/trunk/src/gnome-search/search-date.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-date.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-date.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -30,7 +30,7 @@
 
 #include "gnc-date.h"
 #include "gnc-date-edit.h"
-#include "QueryCore.h"
+#include "qof.h"
 
 #include "search-date.h"
 #include "search-core-utils.h"
@@ -42,7 +42,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_date_class_init	(GNCSearchDateClass *class);
 static void gnc_search_date_init	(GNCSearchDate *gspaper);
@@ -260,7 +260,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchDate *fi = (GNCSearchDate *)fe;
     GNCSearchDatePrivate *priv;

Modified: gnucash/trunk/src/gnome-search/search-double.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-double.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-double.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 
 #include "gnc-amount-edit.h"
-#include "QueryCore.h"
+#include "qof.h"
 
 #include "search-double.h"
 #include "search-core-utils.h"
@@ -41,7 +41,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_double_class_init	(GNCSearchDoubleClass *class);
 static void gnc_search_double_init	(GNCSearchDouble *gspaper);
@@ -254,7 +254,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchDouble *fi = (GNCSearchDouble *)fe;
     GNCSearchDoublePrivate *priv ;

Modified: gnucash/trunk/src/gnome-search/search-int64.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-int64.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-int64.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 
 #include "gnc-amount-edit.h"
-#include "QueryCore.h"
+#include "qof.h"
 
 #include "search-int64.h"
 #include "search-core-utils.h"
@@ -41,7 +41,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_int64_class_init	(GNCSearchInt64Class *class);
 static void gnc_search_int64_init	(GNCSearchInt64 *gspaper);
@@ -261,7 +261,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchInt64 *fi = (GNCSearchInt64 *)fe;
     GNCSearchInt64Private *priv;

Modified: gnucash/trunk/src/gnome-search/search-numeric.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-numeric.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-numeric.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 
 #include "gnc-amount-edit.h"
-#include "QueryCore.h"
+#include "qof.h"
 
 #include "search-numeric.h"
 #include "search-core-utils.h"
@@ -41,7 +41,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_numeric_class_init	(GNCSearchNumericClass *class);
 static void gnc_search_numeric_init	(GNCSearchNumeric *gspaper);
@@ -322,7 +322,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchNumeric *fi = (GNCSearchNumeric *)fe;
     GNCSearchNumericPrivate *priv;

Modified: gnucash/trunk/src/gnome-search/search-reconciled.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-reconciled.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-reconciled.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#include "QueryCore.h"
+#include "qof.h"
 #include "Transaction.h"	/* for ?REC */
 
 #include "search-reconciled.h"
@@ -39,7 +39,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_reconciled_class_init	(GNCSearchReconciledClass *class);
 static void gnc_search_reconciled_init	(GNCSearchReconciled *gspaper);
@@ -242,7 +242,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchReconciled *fi = (GNCSearchReconciled *)fe;
     char chars[6];

Modified: gnucash/trunk/src/gnome-search/search-string.c
===================================================================
--- gnucash/trunk/src/gnome-search/search-string.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-search/search-string.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -33,7 +33,7 @@
 
 #include "search-string.h"
 #include "search-core-utils.h"
-#include "QueryCore.h"
+#include "qof.h"
 
 #define d(x)
 
@@ -42,7 +42,7 @@
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
 static gboolean gncs_validate (GNCSearchCoreType *fe);
 static GtkWidget *gncs_get_widget(GNCSearchCoreType *fe);
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe);
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe);
 
 static void gnc_search_string_class_init	(GNCSearchStringClass *class);
 static void gnc_search_string_init	(GNCSearchString *gspaper);
@@ -335,7 +335,7 @@
     return box;
 }
 
-static QueryPredData_t gncs_get_predicate (GNCSearchCoreType *fe)
+static QofQueryPredData* gncs_get_predicate (GNCSearchCoreType *fe)
 {
     GNCSearchString *ss = (GNCSearchString *)fe;
     QofQueryCompare how;

Modified: gnucash/trunk/src/gnome-utils/gnc-query-list.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-query-list.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-utils/gnc-query-list.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -30,9 +30,9 @@
 #include "gnc-component-manager.h"
 #include "gnc-query-list.h"
 #include "search-param.h"
-#include "QueryCore.h"
 #include "qof.h"
-#include "QueryObject.h"
+#include "qof.h"
+#include "qof.h"
 
 /* Signal codes */
 enum

Modified: gnucash/trunk/src/gnome-utils/search-param.c
===================================================================
--- gnucash/trunk/src/gnome-utils/search-param.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/gnome-utils/search-param.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -30,8 +30,8 @@
 
 #include "gnc-engine.h"
 #include "GNCId.h"
-#include "QueryCore.h"
-#include "QueryObject.h"
+#include "qof.h"
+#include "qof.h"
 
 #include "search-param.h"
 
@@ -183,7 +183,7 @@
     for (; param_path; param_path = param_path->next)
     {
         QofIdType param_name = param_path->data;
-        const QueryObjectDef *objDef =
+        const QofParam *objDef =
             qof_class_get_parameter (search_type, param_name);
 
         /* If it doesn't exist, then we've reached the end */

Modified: gnucash/trunk/src/register/ledger-core/gnc-ledger-display.c
===================================================================
--- gnucash/trunk/src/register/ledger-core/gnc-ledger-display.c	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/register/ledger-core/gnc-ledger-display.c	2010-12-14 20:22:48 UTC (rev 19939)
@@ -27,8 +27,8 @@
 
 #include "Account.h"
 #include "Query.h"
-#include "QueryCore.h"
 #include "qof.h"
+#include "qof.h"
 #include "SX-book.h"
 #include "Transaction.h"
 #include "gnc-component-manager.h"



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/engine/Query.h	2010-12-14 19:50:17 UTC (rev 19938)
+++ gnucash/trunk/src/engine/Query.h	2010-12-14 20:22:48 UTC (rev 19939)
@@ -62,7 +62,7 @@
  *    represented at most once in the returned list.  The caller must
  *    free the GList.
  */
-SplitList   * xaccQueryGetSplitsUniqueTrans(Query *q);
+SplitList   * xaccQueryGetSplitsUniqueTrans(QofQuery *q);
 
 /**
  * The xaccQueryGetTransactions() routine returns a list of
@@ -85,56 +85,56 @@
  *    matching accounts, whereas 'AND' acts as a boolean-AND
  *    for matching accounts.  Whew. Got that?
  */
-TransList   * xaccQueryGetTransactions(Query * q, query_txn_match_t type);
+TransList   * xaccQueryGetTransactions(QofQuery * q, query_txn_match_t type);
 
 /**
  * The xaccQueryGetLots() routine is just like GetTransactions() except
  *    it returns a list of Lots.
  *
  */
-LotList     * xaccQueryGetLots(Query * q, query_txn_match_t type);
+LotList     * xaccQueryGetLots(QofQuery * q, query_txn_match_t type);
 
 /*******************************************************************
  *  match-adding API
  *******************************************************************/
 
-void xaccQueryAddAccountMatch(Query *, AccountList *,
+void xaccQueryAddAccountMatch(QofQuery *, AccountList *,
                               QofGuidMatch how, QofQueryOp op);
 
-void xaccQueryAddAccountGUIDMatch(Query *, AccountGUIDList *,
+void xaccQueryAddAccountGUIDMatch(QofQuery *, AccountGUIDList *,
                                   QofGuidMatch, QofQueryOp);
 
-void xaccQueryAddSingleAccountMatch(Query *, Account *, QofQueryOp);
+void xaccQueryAddSingleAccountMatch(QofQuery *, Account *, QofQueryOp);
 
-void xaccQueryAddStringMatch (Query* q, const char *matchstring,
+void xaccQueryAddStringMatch (QofQuery* q, const char *matchstring,
                               gboolean case_sens, gboolean use_regexp,
                               QofQueryOp op,
                               const char * path, ...);
 void
-xaccQueryAddDescriptionMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddDescriptionMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                              QofQueryOp o);
 void
-xaccQueryAddNumberMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddNumberMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                         QofQueryOp o);
 void
-xaccQueryAddActionMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddActionMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                         QofQueryOp o);
 void
-xaccQueryAddMemoMatch(Query *q, const char *m, gboolean c, gboolean r,
+xaccQueryAddMemoMatch(QofQuery *q, const char *m, gboolean c, gboolean r,
                       QofQueryOp o);
 void
-xaccQueryAddValueMatch(Query *q, gnc_numeric amt, QofNumericMatch sgn,
+xaccQueryAddValueMatch(QofQuery *q, gnc_numeric amt, QofNumericMatch sgn,
                        QofQueryCompare how, QofQueryOp op);
 void
-xaccQueryAddSharePriceMatch(Query *q, gnc_numeric amt, QofQueryCompare how,
+xaccQueryAddSharePriceMatch(QofQuery *q, gnc_numeric amt, QofQueryCompare how,
                             QofQueryOp op);
 void
-xaccQueryAddSharesMatch(Query *q, gnc_numeric amt, QofQueryCompare how,
+xaccQueryAddSharesMatch(QofQuery *q, gnc_numeric amt, QofQueryCompare how,
                         QofQueryOp op);
 void
-xaccQueryAddBalanceMatch(Query *q, QofQueryCompare bal, QofQueryOp op);
+xaccQueryAddBalanceMatch(QofQuery *q, QofQueryCompare bal, QofQueryOp op);
 
-void xaccQueryAddNumericMatch (Query *q, gnc_numeric amount,
+void xaccQueryAddNumericMatch (QofQuery *q, gnc_numeric amount,
                                QofNumericMatch sign, QofQueryCompare how,
                                QofQueryOp op, const char * path, ...);
 
@@ -147,22 +147,22 @@
  *    all transactions are matched.
  */
 
-void xaccQueryAddDateMatch(Query * q, gboolean use_start,
+void xaccQueryAddDateMatch(QofQuery * q, gboolean use_start,
                            int sday, int smonth, int syear,
                            gboolean use_end, int eday, int emonth, int eyear,
                            QofQueryOp op);
-void xaccQueryAddDateMatchTS(Query * q,
+void xaccQueryAddDateMatchTS(QofQuery * q,
                              gboolean use_start, Timespec sts,
                              gboolean use_end, Timespec ets,
                              QofQueryOp op);
-void xaccQueryAddDateMatchTT(Query * q,
+void xaccQueryAddDateMatchTT(QofQuery * q,
                              gboolean use_start, time_t stt,
                              gboolean use_end, time_t ett,
                              QofQueryOp op);
-void xaccQueryGetDateMatchTS (Query * q,
+void xaccQueryGetDateMatchTS (QofQuery * q,
                               Timespec * sts,
                               Timespec * ets);
-void xaccQueryGetDateMatchTT (Query * q,
+void xaccQueryGetDateMatchTT (QofQuery * q,
                               time_t * stt,
                               time_t * ett);
 
@@ -177,19 +177,19 @@
     CLEARED_ALL        = 0x001F
 } cleared_match_t;
 
-void xaccQueryAddClearedMatch(Query * q, cleared_match_t how, QofQueryOp op);
-void xaccQueryAddGUIDMatch(Query * q, const GncGUID *guid,
+void xaccQueryAddClearedMatch(QofQuery * q, cleared_match_t how, QofQueryOp op);
+void xaccQueryAddGUIDMatch(QofQuery * q, const GncGUID *guid,
                            QofIdType id_type, QofQueryOp op);
 
 /** given kvp value is on right side of comparison */
-void xaccQueryAddKVPMatch(Query *q, GSList *path, const KvpValue *value,
+void xaccQueryAddKVPMatch(QofQuery *q, GSList *path, const KvpValue *value,
                           QofQueryCompare how, QofIdType id_type,
                           QofQueryOp op);
 
 /*******************************************************************
  *  compatibility interface with old Query API
  *******************************************************************/
-time_t xaccQueryGetEarliestDateFound(Query * q);
-time_t xaccQueryGetLatestDateFound(Query * q);
+time_t xaccQueryGetEarliestDateFound(QofQuery * q);
+time_t xaccQueryGetLatestDateFound(QofQuery * q);
 
 #endif
@@ -177,19 +177,19 @@
 
 /*******************************************************************
- *  compatibility interface with old Query API
+ *  compatibility interface with old QofQuery API
  *******************************************************************/

Deleted: gnucash/trunk/src/engine/QueryCore.h
===================================================================